@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -21,6 +21,7 @@
 
 package com.openexchange.authentication.oauth.impl;
 
+import java.util.Map;
 import com.openexchange.exception.OXException;
 import com.openexchange.mail.api.AuthType;
 import com.openexchange.mail.api.AuthenticationFailedHandler;
@@ -37,12 +38,15 @@ import com.openexchange.session.Session;
  */
 public class PasswordGrantAuthenticationFailedHandler implements AuthenticationFailedHandler {
 
+    /**
+     * Initializes a new {@link PasswordGrantAuthenticationFailedHandler}.
+     */
     public PasswordGrantAuthenticationFailedHandler() {
         super();
     }
 
     @Override
-    public AuthenticationFailureHandlerResult handleAuthenticationFailed(OXException failedAuthentication, Service service, MailConfig mailConfig, Session session) throws OXException {
+    public AuthenticationFailureHandlerResult handleAuthenticationFailed(OXException failedAuthentication, Service service, MailConfig mailConfig, Session session, Map<String, Object> state) throws OXException {
         if (AuthType.isOAuthType(mailConfig.getAuthType()) && Boolean.TRUE.equals(session.getParameter(SessionParameters.PASSWORD_GRANT_MARKER))) {
             // re-throw; let SessionInspector handle eager refresh alone
             return AuthenticationFailureHandlerResult.createErrorResult(failedAuthentication);
